| Field                                           | Response                                                                                                                                                                                                          |
| :---------------------------------------------- | :---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| Model Application(s):                           | Synethic Audio Generation                                                                                                                                                                                         |
| Describe the life critical impact (if present). | Not Applicable                                                                                                                                                                                                    |
| Use Case Restrictions:                          | None                                                                                                                                                                                                              |
| Model and dataset restrictions:                 | The Principle of least privilege (PoLP) is applied limiting access for dataset generation and model development. Restrictions enforce dataset access during training, and dataset license constraints adhered to. |
